# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tabs(Component):
    """A Tabs component.
Lazy loaded Tabs

@param {
	id,
 tabHeadings,
 defaultTab,
 children,
} [props={}]
@return {*}

Keyword arguments:

- children (list of a list of or a singular dash component, string or numbers; optional):
    Array of accordion children.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- defaultTab (number; optional):
    The default active tab.

- tabHeadings (list of strings; optional):
    Array of accordion headings."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'uk_gov_dash_components'
    _type = 'Tabs'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, tabHeadings=Component.UNDEFINED, defaultTab=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'defaultTab', 'tabHeadings']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'defaultTab', 'tabHeadings']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Tabs, self).__init__(children=children, **args)



from dash.testing.application_runners import import_app


# Basic test for the component rendering.
# The dash_duo pytest fixture is installed with dash (v1.0+)
def test_render_component(dash_duo):
    # Start a dash app contained as the variable `app` in `usage.py`
    app = import_app("usage")
    dash_duo.start_server(app)

    # Get the generated component input with selenium
    # The html input will be a children of the #input dash component
    my_component = dash_duo.find_element("#input > input")

    assert "my-value" == my_component.get_attribute("value")

    # Clear the input
    dash_duo.clear_input(my_component)

    # Send keys to the custom input.
    my_component.send_keys("Hello dash")

    # Wait for the text to equal, if after the timeout (default 10 seconds)
    # the text is not equal it will fail the test.
    dash_duo.wait_for_text_to_equal("#output", "You have entered Hello dash")



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class ExpandableMenuItem(Component):
    """An ExpandableMenuItem component.
Lazy loaded ExpandableMenuItem

@param {
	id,
 title,
 collapsedByDefault,
 children,
 expandedClass,
 collapsedClass,
 ariaLabel,
 subMenuClass,
 titleClass,
} [props={}]
@return {*}

Keyword arguments:

- children (list; optional):
    An array of li HTML elements that will displayed on click.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- ariaLabel (string; optional):
    Accessible text to describe the expandable menu element, attached
    to Li element that wraps the children.

- collapsedByDefault (boolean; default True):
    Default behaviour of whether or not the sub-menu is collapsed on
    load.

- collapsedClass (string; optional):
    CSS class that will be applied when the menu is collapsed.

- expandedClass (string; optional):
    CSS class that will be applied when the menu is expanded.

- subMenuClass (string; optional):
    CSS class that will be applied to the sub nav menu.

- title (string; optional):
    The clickable text to display sub-menu.

- titleClass (string; optional):
    CSS class that will be applied to the title of the sub nav menu."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'uk_gov_dash_components'
    _type = 'ExpandableMenuItem'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, title=Component.UNDEFINED, collapsedByDefault=Component.UNDEFINED, expandedClass=Component.UNDEFINED, collapsedClass=Component.UNDEFINED, ariaLabel=Component.UNDEFINED, subMenuClass=Component.UNDEFINED, titleClass=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'ariaLabel', 'collapsedByDefault', 'collapsedClass', 'expandedClass', 'subMenuClass', 'title', 'titleClass']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'ariaLabel', 'collapsedByDefault', 'collapsedClass', 'expandedClass', 'subMenuClass', 'title', 'titleClass']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(ExpandableMenuItem, self).__init__(children=children, **args)
